@@ -121,7 +121,7 @@ def third_person_personal_pronoun(name, country_id=None, language_id=None):
 		- `country_id` -- Restrict name lookup for a specific country (*default:* `None`)
 		- `language_id` -- Restrict name lookup for a specific language (*default:* `None`)
 	"""
-	return 'he' if is_male(name=name, country_id=country_id, language_id=language_id) else return 'she'
+	return 'he' if is_male(name=name, country_id=country_id, language_id=language_id) else 'she'
 
 def possessive_determiner(name, country_id=None, language_id=None):
 	"""Return the possessive determiner ('his' or 'her'; see http://en.wikipedia.org/wiki/Possessive_determiner for more) for the given name
